==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/actions/duplicateItem.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/actions/duplicateItem", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = duplicateItem;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function duplicateItem(_ref) {
      var _ref$addedFragmentEnt = _ref.addedFragmentEntryLinks,
          addedFragmentEntryLinks = _ref$addedFragmentEnt === void 0 ? [] : _ref$addedFragmentEnt,
          itemId = _ref.itemId,
          layoutData = _ref.layoutData;
      return {
        addedFragmentEntryLinks: addedFragmentEntryLinks,
        itemId: itemId,
        layoutData: layoutData,
        type: _types.DUPLICATE_ITEM
      };
    }
    //# sourceMappingURL=duplicateItem.js.map
  }
});
//# sourceMappingURL=duplicateItem.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/actions/duplicateItem.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/actions/duplicateItem", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = duplicateItem;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function duplicateItem(_ref) {
      var _ref$addedFragmentEnt = _ref.addedFragmentEntryLinks,
          addedFragmentEntryLinks = _ref$addedFragmentEnt === void 0 ? [] : _ref$addedFragmentEnt,
          itemId = _ref.itemId,
          layoutData = _ref.layoutData;
      return {
        addedFragmentEntryLinks: addedFragmentEntryLinks,
        itemId: itemId,
        layoutData: layoutData,
        type: _types.DUPLICATE_ITEM
      };
    }
    //# sourceMappingURL=duplicateItem.js.map
  }
});
//# sourceMappingURL=duplicateItem.js.map
